@@ -375,8 +375,10 @@ def load_dataset_local(variables: Dict[str, Any], key: str) -> Any:
         workflow_id = exp_engine_metadata["wf_id"]
         if task_name in execution_engine_mapping:
             inputs = execution_engine_mapping[task_name]
-            output_name = inputs["file_name"]
-            source_task = inputs["source_task"]
+            if key in inputs:
+                input_map = inputs[key]
+                output_name = input_map["file_name"]
+                source_task = input_map["source_task"]
             # if key in execution_engine_mapping[task_name]:
             #     key = execution_engine_mapping[task_name][key]
         task_folder = os.path.join("/shared", workflow_id, source_task)
